@@ -1,3 +1,7 @@
+from os import cpu_count
+from re import sub
+
+from git import exc
 from package_locator.common import *
 from package_locator.directory import *
 import requests
@@ -13,8 +17,12 @@ def get_npm_location(package):
     directory = data["repository"].get("directory", None)
     if directory:
         return repo_url, directory
-    subdir = get_npm_subdir(package, repo_url)
-    return repo_url, subdir
+    try:
+        subdir = get_npm_subdir(package, repo_url)
+        return repo_url, subdir
+    except Exception as e:
+        print(e)
+        return repo_url, None
 
 
 def get_rubygems_location(package):
@@ -24,10 +32,10 @@ def get_rubygems_location(package):
     if repo_url:
         try:
             subdir = get_rubygems_subdir(package, repo_url)
-            if subdir:
-                return repo_url, subdir
-        except NotPackageRepository:
-            return None
+            return repo_url, subdir
+        except Exception as e:
+            print(e)
+            return repo_url, None
 
     urls = search_for_github_repo(data)
     for url in urls:
@@ -35,21 +43,26 @@ def get_rubygems_location(package):
             url = get_base_repo_url(url)
             subdir = get_rubygems_subdir(package, url)
             return url, subdir
-        except NotPackageRepository:
+        except Exception as e:
+            print(e)
             continue
+    return None, None
 
 
 def get_pypi_location(package):
     url = "https://pypi.org/pypi/{}/json".format(package)
     data = json.loads(requests.get(url).content)
-    repo_url = get_base_repo_url(data["info"].get("project_urls", {}).get("Source Code", None))
+    try:
+        repo_url = get_base_repo_url(data["info"]["project_urls"]["Source Code"])
+    except:
+        repo_url = None
+
     if repo_url:
         try:
             subdir = get_pypi_subdir(package, repo_url)
-            if subdir:
-                return repo_url, subdir
-        except NotPackageRepository:
-            return None
+            return repo_url, subdir
+        except:
+            return repo_url, None
 
     urls = search_for_github_repo(data)
     for url in urls:
@@ -57,22 +70,42 @@ def get_pypi_location(package):
             url = get_base_repo_url(url)
             subdir = get_pypi_subdir(package, url)
             return url, subdir
-        except NotPackageRepository:
+        except:
             continue
 
+    try:
+        homepage = data["info"]["home_page"]
+    except:
+        homepage = None
+    if homepage:
+        homepage = {"body": requests.get(homepage).text}
+        urls = search_for_github_repo(homepage)
+        for url in urls:
+            try:
+                url = get_base_repo_url(url)
+                subdir = get_pypi_subdir(package, url)
+                return url, subdir
+            except:
+                continue
+
+    return None, None
+
 
 def get_composer_location(package):
     url = "https://repo.packagist.org/p2/{}.json".format(package)
     data = json.loads(requests.get(url).content)
     data = data["packages"][package][0]
-    repo_url = get_base_repo_url(data.get("source", {}).get("url", None))
+    try:
+        repo_url = get_base_repo_url(data["source"]["url"])
+    except:
+        repo_url = None
+
     if repo_url:
         try:
             subdir = get_composer_subdir(package, repo_url)
-            if subdir:
-                return repo_url, subdir
-        except NotPackageRepository:
-            return None
+            return repo_url, subdir
+        except:
+            return repo_url, None
 
     urls = search_for_github_repo(data)
     for url in urls:
@@ -80,22 +113,21 @@ def get_composer_location(package):
             url = get_base_repo_url(url)
             subdir = get_composer_subdir(package, url)
             return url, subdir
-        except NotPackageRepository:
+        except:
             continue
+    return None, None
 
 
 def get_cargo_location(package):
     url = "https://crates.io/api/v1/crates/{}".format(package)
-    data = json.loads(requests.get(url).content)
-    data = data["crate"]
+    data = json.loads(requests.get(url).content)["crate"]
     repo_url = get_base_repo_url(data.get("repository", None))
     if repo_url:
         try:
             subdir = get_cargo_subdir(package, repo_url)
-            if subdir:
-                return repo_url, subdir
-        except NotPackageRepository:
-            return None
+            return repo_url, subdir
+        except:
+            return repo_url, None
 
     urls = search_for_github_repo(data)
     for url in urls:
@@ -103,18 +135,27 @@ def get_cargo_location(package):
             url = get_base_repo_url(url)
             subdir = get_cargo_subdir(package, url)
             return url, subdir
-        except NotPackageRepository:
+        except:
             continue
+    return None, None
 
 
 def get_repository_url_and_subdir(ecosystem, package):
     if ecosystem == NPM:
-        return get_npm_location(package)
+        repo_url, subdir = get_npm_location(package)
     elif ecosystem == PYPI:
-        return get_pypi_location(package)
+        repo_url, subdir = get_pypi_location(package)
     elif ecosystem == RUBYGEMS:
-        return get_rubygems_location(package)
+        repo_url, subdir = get_rubygems_location(package)
     elif ecosystem == COMPOSER:
-        return get_composer_location(package)
+        repo_url, subdir = get_composer_location(package)
     elif ecosystem == CARGO:
-        return get_cargo_location(package)
+        repo_url, subdir = get_cargo_location(package)
+
+    if repo_url and subdir is not None:
+        subdir = subdir.removesuffix("/").removesuffix(".")
+        if not subdir.startswith("./"):
+            subdir = "./" + subdir
+        repo_url = get_base_repo_url(repo_url)
+
+    return repo_url, subdir
